@@ -1,4 +1,5 @@
 globalVariables(c("value", "sigma", "condition", "x", "y", "name", "proflist", "delta",
                   "sigmaLS", "cbLower95", "cbUpper95", "cbLower68", "cbUpper68",
                   "iteration", "idx", "is.zero", "index", "converged", "iterations",
-                  ".runbgOutput", "terminal", "parvalue", "dataErrModel"))
+                  ".runbgOutput", "terminal", "parvalue", "dataErrorModel",
+                  "Rate"))
